(function (global, factory) {
  typeof exports === 'object' && typeof module !== 'undefined' ? module.exports = factory() :
  typeof define === 'function' && define.amd ? define(factory) :
  (global = typeof globalThis !== 'undefined' ? globalThis : global || self, global.textics = factory());
}(this, (function () {
  /**
   * Counts lines, words, chars and spaces for a given string.
   *
   * @param {string} str
   * @returns
   */
  function textics(str) {
    if (typeof str !== "string") {
      throw new TypeError("Input is not string!");
    }

    var lines = 0;
    var words = 0;
    var chars = 0;
    var spaces = 0;
    /**
     * Getting total string length.
     */

    var totalInputLength = str.length;
    if (totalInputLength === 0) return {
      lines: lines,
      words: words,
      chars: chars,
      spaces: spaces
    };
    var splittedByLines = str.split(/(?:\r?\n)/g) || [];
    lines = splittedByLines.length;
    splittedByLines.forEach(function (line) {
      var lineLength = line.length;
      var trimmedLine = line.trim();
      var trimmedLineLength = trimmedLine.length;
      /**
       * Calculates outer space.
       */

      spaces += lineLength - trimmedLineLength;
      /**
       * When zero, empty line.
       */

      if (trimmedLineLength !== 0) {
        var splittedBySpaces = trimmedLine.split(/\s/g);
        var wordsInLine = splittedBySpaces.length;
        words += wordsInLine;
        /**
         * if zero, then it's one word without spaces
         */

        if (wordsInLine > 1) {
          /**
           * ["w1", "w2", "w3"].length = 3.
           * How many spaces? length -1
           */
          spaces += wordsInLine - 1;
        }

        splittedBySpaces.forEach(function (word) {
          chars += word.length;
        });
      }
    });
    return {
      lines: lines,
      words: words,
      chars: chars,
      spaces: spaces
    };
  }

  var textics_1 = {
    textics: textics
  };

  return textics_1;

})));
//# sourceMappingURL=textics.umd.js.map
